=============
bisos.py3-all
=============

.. contents::
   :depth: 3
..

Overview
========

bisos.py3-all: is a top level module that requires core BISOS (ByStar
Internet Services OS) modules.

Main required modules are:

bisos.py3-all: is a top level module that requires core BISOS and all
BISOS Pkgs (Feature Areas).

In addition to bisos.core, bisos.py3-all required modules are:

-  bisos.provision

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in
http://www.by-star.net/PLPC/180047

Installation
============

::

   sudo pip install bisos.examples

Usage
=====

::

   This is a vitual package which simply requires other packages.
